==> Text-SlackEmoji-0.002.tar.gz: Text-SlackEmoji-0.002/share/emoji.pl <==
use charnames ':full';
return {
  '+1' => "\N{THUMBS UP SIGN}",
  '-1' => "\N{THUMBS DOWN SIGN}",

  'ab'                    => "\N{NEGATIVE SQUARED AB}",
  'angry'                 => "\N{ANGRY FACE}",
  'anguished'             => "\N{ANGUISHED FACE}",
  'blush'                 => "\N{SMILING FACE WITH SMILING EYES}",
  'coffee'                => "\N{HOT BEVERAGE}",
  'confounded'            => "\N{CONFOUNDED FACE}",
  'confused'              => "\N{CONFUSED FACE}",
  'cry'                   => "\N{CRYING FACE}",
  'disappointed'          => "\N{DISAPPOINTED FACE}",
  'disappointed_relieved' => "\N{DISAPPOINTED BUT RELIEVED FACE}",
  'expressionless'        => "\N{EXPRESSIONLESS FACE}",
  'facepunch'             => "\N{FISTED HAND SIGN}",
  'fearful'               => "\N{FEARFUL FACE}",
  'fist'                  => "\N{RAISED FIST}",
  'frowning'              => "\N{FROWNING FACE WITH OPEN MOUTH}",
  'grin'                  => "\N{GRINNING FACE WITH SMILING EYES}",
  'grinning'              => "\N{GRINNING FACE}",
  'headphones'            => "\N{HEADPHONE}",
  'heart'                 => "\N{BLACK HEART SUIT}\x{FE0F}",
  'heart_eyes'            => "\N{SMILING FACE WITH HEART-SHAPED EYES}",
  'imp'                   => "\N{IMP}",
  'innocent'              => "\N{SMILING FACE WITH HALO}",
  'joy'                   => "\N{FACE WITH TEARS OF JOY}",
  'kissing'               => "\N{KISSING FACE}",
  'kissing_closed_eyes'   => "\N{KISSING FACE WITH CLOSED EYES}",
  'kissing_heart'         => "\N{FACE THROWING A KISS}",
  'kissing_smiling_eyes'  => "\N{KISSING FACE WITH SMILING EYES}",
  'monkey',               => "\N{MONKEY}",
  'monkey_face',          => "\N{MONKEY FACE}",
  'microphone'            => "\N{MICROPHONE}",
  'microphone'            => "\N{MICROPHONE}",
  'neutral_face'          => "\N{NEUTRAL FACE}",
  'ok'                    => "\N{SQUARED OK}",
  'ok_hand'               => "\N{OK HAND SIGN}",
  'pensive'               => "\N{PENSIVE FACE}",
  'persevere'             => "\N{PERSEVERING FACE}",
  'phone'                 => "\N{BLACK TELEPHONE}\x{FE0F}",
  'poop'                  => "\N{PILE OF POO}",
  'pouting_cat'           => "\N{POUTING CAT FACE}",
  'rage'                  => "\N{POUTING FACE}",
  'rage'                  => "\N{POUTING FACE}",
  'relaxed'               => "\N{WHITE SMILING FACE}",
  'relieved'              => "\N{RELIEVED FACE}",
  'satisfied'   => "\N{SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES}",
  'saxophone'             => "\N{SAXOPHONE}",

  # This should really be SLIGHTLY SMILING FACE, but OS X 10.11.0 and iOS 9.0
  # do not have this glyph.  Apparently it's in iOS 9.1. -- rjbs, 2015-10-12
  'simple_smile' => "\N{SMILING FACE WITH SMILING EYES}",

  'smile'       => "\N{SMILING FACE WITH OPEN MOUTH AND SMILING EYES}",
  'smiley'      => "\N{SMILING FACE WITH OPEN MOUTH}",
  'smiling_imp' => "\N{SMILING FACE WITH HORNS}",
  'smirk'       => "\N{SMIRKING FACE}",
  'snowman'     => "\N{SNOWMAN}",
  'sunglasses'  => "\N{SMILING FACE WITH SUNGLASSES}",
  'sweat'       => "\N{FACE WITH COLD SWEAT}",
  'sweat_smile' => "\N{SMILING FACE WITH OPEN MOUTH AND COLD SWEAT}",
  'telephone'   => "\N{BLACK TELEPHONE}\x{FE0F}",
  'tongue'      => "\N{TONGUE}",
  'triumph'     => "\N{FACE WITH LOOK OF TRIUMPH}",
  'unamused'    => "\N{UNAMUSED FACE}",
  'wave'        => "\N{WAVING HAND SIGN}",
  'weary'       => "\N{WEARY FACE}",
  'wink'        => "\N{WINKING FACE}",
  'worried'     => "\N{WORRIED FACE}",
  'yum'         => "\N{FACE SAVOURING DELICIOUS FOOD}",

  'telephone_receiver'  => "\N{TELEPHONE RECEIVER}",
  'stuck_out_tongue'    => "\N{FACE WITH STUCK-OUT TONGUE}",
  'stuck_out_tongue_closed_eyes' => "\N{FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES}",
  'stuck_out_tongue_winking_eyes' => "\N{FACE WITH STUCK-OUT TONGUE AND WINKING EYE}",

  'see_no_evil'   => "\N{SEE-NO-EVIL MONKEY}",
  'hear_no_evil'  => "\N{HEAR-NO-EVIL MONKEY}",
  'speak_no_evil' => "\N{SPEAK-NO-EVIL MONKEY}",
};

==> Text-SlackEmoji-0.003.tar.gz: Text-SlackEmoji-0.003/share/emoji.pl <==
use charnames ':full';
return {
  '+1' => "\N{THUMBS UP SIGN}",
  '-1' => "\N{THUMBS DOWN SIGN}",

  'ab'                    => "\N{NEGATIVE SQUARED AB}",
  'angry'                 => "\N{ANGRY FACE}",
  'anguished'             => "\N{ANGUISHED FACE}",
  'blush'                 => "\N{SMILING FACE WITH SMILING EYES}",
  'cat'                   => "\N{CAT FACE}",
  'cat2'                  => "\N{CAT}",
  'coffee'                => "\N{HOT BEVERAGE}",
  'confounded'            => "\N{CONFOUNDED FACE}",
  'confused'              => "\N{CONFUSED FACE}",
  'cry'                   => "\N{CRYING FACE}",
  'disappointed'          => "\N{DISAPPOINTED FACE}",
  'disappointed_relieved' => "\N{DISAPPOINTED BUT RELIEVED FACE}",
  'dog'                   => "\N{DOG FACE}",
  'dog2'                  => "\N{DOG}",
  'dragon'                => "\N{DRAGON}",
  'dragon_face'           => "\N{DRAGON FACE}",
  'eggplant'              => "\N{AUBERGINE}",
  'expressionless'        => "\N{EXPRESSIONLESS FACE}",
  'facepunch'             => "\N{FISTED HAND SIGN}",
  'fearful'               => "\N{FEARFUL FACE}",
  'fist'                  => "\N{RAISED FIST}",
  'frowning'              => "\N{FROWNING FACE WITH OPEN MOUTH}",
  'grin'                  => "\N{GRINNING FACE WITH SMILING EYES}",
  'grinning'              => "\N{GRINNING FACE}",
  'headphones'            => "\N{HEADPHONE}",
  'heart'                 => "\N{BLACK HEART SUIT}\x{FE0F}",
  'heart_eyes'            => "\N{SMILING FACE WITH HEART-SHAPED EYES}",
  'imp'                   => "\N{IMP}",
  'innocent'              => "\N{SMILING FACE WITH HALO}",
  'joy'                   => "\N{FACE WITH TEARS OF JOY}",
  'kissing'               => "\N{KISSING FACE}",
  'kissing_closed_eyes'   => "\N{KISSING FACE WITH CLOSED EYES}",
  'kissing_heart'         => "\N{FACE THROWING A KISS}",
  'kissing_smiling_eyes'  => "\N{KISSING FACE WITH SMILING EYES}",
  'monkey',               => "\N{MONKEY}",
  'monkey_face',          => "\N{MONKEY FACE}",
  'mouse'                 => "\N{MOUSE FACE}",
  'mouse2'                => "\N{MOUSE}",
  'microphone'            => "\N{MICROPHONE}",
  'microphone'            => "\N{MICROPHONE}",
  'neutral_face'          => "\N{NEUTRAL FACE}",
  'ok'                    => "\N{SQUARED OK}",
  'ok_hand'               => "\N{OK HAND SIGN}",
  'pensive'               => "\N{PENSIVE FACE}",
  'persevere'             => "\N{PERSEVERING FACE}",
  'phone'                 => "\N{BLACK TELEPHONE}\x{FE0F}",
  'poop'                  => "\N{PILE OF POO}",
  'pouting_cat'           => "\N{POUTING CAT FACE}",
  'rage'                  => "\N{POUTING FACE}",
  'rage'                  => "\N{POUTING FACE}",
  'relaxed'               => "\N{WHITE SMILING FACE}",
  'relieved'              => "\N{RELIEVED FACE}",
  'satisfied'   => "\N{SMILING FACE WITH OPEN MOUTH AND TIGHTLY-CLOSED EYES}",
  'saxophone'             => "\N{SAXOPHONE}",

  # This should really be SLIGHTLY SMILING FACE, but OS X 10.11.0 and iOS 9.0
  # do not have this glyph.  Apparently it's in iOS 9.1. -- rjbs, 2015-10-12
  'simple_smile' => "\N{SMILING FACE WITH SMILING EYES}",

  'smile'       => "\N{SMILING FACE WITH OPEN MOUTH AND SMILING EYES}",
  'smiley'      => "\N{SMILING FACE WITH OPEN MOUTH}",
  'smiling_imp' => "\N{SMILING FACE WITH HORNS}",
  'smirk'       => "\N{SMIRKING FACE}",
  'snowman'     => "\N{SNOWMAN}",
  'sunglasses'  => "\N{SMILING FACE WITH SUNGLASSES}",
  'sweat'       => "\N{FACE WITH COLD SWEAT}",
  'sweat_smile' => "\N{SMILING FACE WITH OPEN MOUTH AND COLD SWEAT}",
  'telephone'   => "\N{BLACK TELEPHONE}\x{FE0F}",
  'tongue'      => "\N{TONGUE}",
  'triumph'     => "\N{FACE WITH LOOK OF TRIUMPH}",
  'unamused'    => "\N{UNAMUSED FACE}",
  'wave'        => "\N{WAVING HAND SIGN}",
  'weary'       => "\N{WEARY FACE}",
  'wink'        => "\N{WINKING FACE}",
  'worried'     => "\N{WORRIED FACE}",
  'yum'         => "\N{FACE SAVOURING DELICIOUS FOOD}",

  'telephone_receiver'  => "\N{TELEPHONE RECEIVER}",
  'stuck_out_tongue'    => "\N{FACE WITH STUCK-OUT TONGUE}",
  'stuck_out_tongue_closed_eyes' => "\N{FACE WITH STUCK-OUT TONGUE AND TIGHTLY-CLOSED EYES}",
  'stuck_out_tongue_winking_eyes' => "\N{FACE WITH STUCK-OUT TONGUE AND WINKING EYE}",

  'see_no_evil'   => "\N{SEE-NO-EVIL MONKEY}",
  'hear_no_evil'  => "\N{HEAR-NO-EVIL MONKEY}",
  'speak_no_evil' => "\N{SPEAK-NO-EVIL MONKEY}",
};
